@@ -18,8 +18,6 @@
     02110-1301, USA.
 */
 
-//krazy:excludeall=null since used by SASL (C library)
-
 #include "session.h"
 #include "response.h"
 #include "sievejob_p.h"
@@ -37,6 +35,22 @@
 #include <QTimer>
 #include <QUrlQuery>
 
+#if QT_VERSION < QT_VERSION_CHECK(5,7,0)
+namespace QtPrivate
+{
+template <typename T> struct QAddConst {
+    typedef const T Type;
+};
+}
+
+// this adds const to non-const objects (like std::as_const)
+template <typename T>
+Q_DECL_CONSTEXPR typename QtPrivate::QAddConst<T>::Type &qAsConst(T &t) Q_DECL_NOTHROW { return t; }
+// prevent rvalue arguments:
+template <typename T>
+void qAsConst(const T &&) Q_DECL_EQ_DELETE;
+#endif
+
 using namespace KManageSieve;
 
 Q_DECLARE_METATYPE(KManageSieve::AuthDetails)
@@ -46,7 +60,7 @@ Q_DECLARE_METATYPE(KSslErrorUiData)
 Session::Session(QObject *parent) :
     QObject(parent),
     m_thread(new SessionThread(this)),
-    m_currentJob(Q_NULLPTR),
+    m_currentJob(nullptr),
     m_state(None),
     m_supportsStartTls(false),
     m_connected(false),
@@ -98,7 +112,7 @@ void Session::disconnectFromHost(bool sendLogout)
     if (m_currentJob) {
         killJob(m_currentJob, KJob::EmitResult);
     }
-    Q_FOREACH (SieveJob *job, m_jobs) {
+    for (SieveJob *job : qAsConst(m_jobs)) {
         killJob(job, KJob::EmitResult);
     }
     deleteLater();
@@ -120,7 +134,7 @@ void Session::processResponse(const KManageSieve::Response &response, const QByt
                         return;
                     }
                     if (!allowUnencrypted() && QSslSocket::supportsSsl() && !m_supportsStartTls &&
-                            KMessageBox::warningContinueCancel(Q_NULLPTR,
+                            KMessageBox::warningContinueCancel(nullptr,
                                     i18n("TLS encryption was requested, but your Sieve server does not advertise TLS in its capabilities.\n"
                                          "You can choose to try to initiate TLS negotiations nonetheless, or cancel the operation."),
                                     i18n("Server Does Not Advertise TLS"), KGuiItem(i18n("&Start TLS nonetheless")), KStandardGuiItem::cancel(),
@@ -176,7 +190,7 @@ void Session::processResponse(const KManageSieve::Response &response, const QByt
     default:
         if (m_currentJob) {
             if (m_currentJob->d->handleResponse(response, data)) {
-                m_currentJob = Q_NULLPTR;
+                m_currentJob = nullptr;
                 QMetaObject::invokeMethod(this, "executeNextJob", Qt::QueuedConnection);
             }
             break;
@@ -205,7 +219,7 @@ void Session::killJob(SieveJob *job, KJob::KillVerbosity verbosity)
         if (verbosity == KJob::EmitResult) {
             m_currentJob->d->killed();
         }
-        m_currentJob = Q_NULLPTR;
+        m_currentJob = nullptr;
     } else {
         m_jobs.removeAll(job);
         if (verbosity == KJob::EmitResult) {
@@ -281,7 +295,7 @@ KManageSieve::AuthDetails Session::requestAuthDetails(const QUrl &url)
 
     QPointer<KPasswordDialog> dlg =
         new KPasswordDialog(
-        Q_NULLPTR,
+        nullptr,
         KPasswordDialog::ShowUsernameLine | KPasswordDialog::ShowKeepPassword
     );
     dlg->setUsername(ai.username);
