@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -27,7 +27,7 @@ class SelectMimeTypeComboBox : public KComboBox
 {
     Q_OBJECT
 public:
-    explicit SelectMimeTypeComboBox(QWidget *parent = Q_NULLPTR);
+    explicit SelectMimeTypeComboBox(QWidget *parent = nullptr);
     ~SelectMimeTypeComboBox();
 
     QString code() const;
