@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,16 +29,11 @@
 #include <QGridLayout>
 
 using namespace KSieveUi;
-SieveActionConvert::SieveActionConvert(QObject *parent)
-    : SieveAction(QStringLiteral("convert"), i18n("Convert"), parent)
+SieveActionConvert::SieveActionConvert(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveAction(sieveGraphicalModeWidget, QStringLiteral("convert"), i18n("Convert"), parent)
 {
 }
 
-SieveAction *SieveActionConvert::newAction()
-{
-    return new SieveActionConvert;
-}
-
 QWidget *SieveActionConvert::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
