@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,16 +29,11 @@
 #include "libksieve_debug.h"
 
 using namespace KSieveUi;
-SieveActionKeep::SieveActionKeep(QObject *parent)
-    : SieveAction(QStringLiteral("keep"), i18n("Keep"), parent)
+SieveActionKeep::SieveActionKeep(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveAction(sieveGraphicalModeWidget, QStringLiteral("keep"), i18n("Keep"), parent)
 {
-    mHasImapFlag4Support = SieveEditorGraphicalModeWidget::sieveCapabilities().contains(QStringLiteral("imap4flags"));
-    mHasFlagSupport = SieveEditorGraphicalModeWidget::sieveCapabilities().contains(QStringLiteral("imapflags")) || mHasImapFlag4Support;
-}
-
-SieveAction *SieveActionKeep::newAction()
-{
-    return new SieveActionKeep;
+    mHasImapFlag4Support = sieveCapabilities().contains(QStringLiteral("imap4flags"));
+    mHasFlagSupport = sieveCapabilities().contains(QStringLiteral("imapflags")) || mHasImapFlag4Support;
 }
 
 QString SieveActionKeep::code(QWidget *w) const
@@ -77,7 +72,7 @@ QWidget *SieveActionKeep::createParamWidget(QWidget *parent) const
         lay->addWidget(flagsWidget);
         return w;
     } else {
-        return Q_NULLPTR;
+        return nullptr;
     }
 }
 
