@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -32,16 +32,11 @@
 
 using namespace KSieveUi;
 
-SieveActionRedirect::SieveActionRedirect(QObject *parent)
-    : SieveAction(QStringLiteral("redirect"), i18n("Redirect"), parent)
+SieveActionRedirect::SieveActionRedirect(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveAction(sieveGraphicalModeWidget, QStringLiteral("redirect"), i18n("Redirect"), parent)
 {
-    mHasCopySupport = SieveEditorGraphicalModeWidget::sieveCapabilities().contains(QStringLiteral("copy"));
-    mHasListSupport = SieveEditorGraphicalModeWidget::sieveCapabilities().contains(QStringLiteral("extlists"));
-}
-
-SieveAction *SieveActionRedirect::newAction()
-{
-    return new SieveActionRedirect;
+    mHasCopySupport = sieveCapabilities().contains(QStringLiteral("copy"));
+    mHasListSupport = sieveCapabilities().contains(QStringLiteral("extlists"));
 }
 
 QWidget *SieveActionRedirect::createParamWidget(QWidget *parent) const
