@@ -70,8 +70,8 @@ QString SieveConditionBody::code(QWidget *w) const
     const QString matchValue = matchType->code(isNegative);
 
     QLineEdit *edit = w->findChild<QLineEdit *>(QStringLiteral("edit"));
-    const QString editValue = edit->text();
-    return AutoCreateScriptUtil::negativeString(isNegative) + QStringLiteral("body %1 %2 \"%3\"").arg(bodyValue, matchValue, editValue);
+    const QString editValue = AutoCreateScriptUtil::createAddressList(edit->text().trimmed(), false);
+    return AutoCreateScriptUtil::negativeString(isNegative) + QStringLiteral("body %1 %2 %3").arg(bodyValue, matchValue, editValue);
 }
 
 QStringList SieveConditionBody::needRequires(QWidget *) const
@@ -101,6 +101,7 @@ bool SieveConditionBody::setParamWidgetValue(const QDomElement &element, QWidget
     QStringList tagValueList;
     QStringList strValue;
 
+    bool wasListElement = false;
     QDomNode node = element.firstChild();
     while (!node.isNull()) {
         QDomElement e = node.toElement();
@@ -124,6 +125,10 @@ bool SieveConditionBody::setParamWidgetValue(const QDomElement &element, QWidget
                 //nothing
             } else if (tagName == QLatin1String("comment")) {
                 //implement in the future ?
+            } else if (tagName == QLatin1String("list")) {
+                strValue << AutoCreateScriptUtil::listValueToStr(e);
+                wasListElement = true;
+                ++indexStr;
             } else {
                 unknownTag(tagName, error);
                 qCDebug(LIBKSIEVE_LOG) << " SieveConditionBody::setParamWidgetValue unknown tagName " << tagName;
@@ -138,7 +143,7 @@ bool SieveConditionBody::setParamWidgetValue(const QDomElement &element, QWidget
         SelectMatchTypeComboBox *matchType = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
         matchType->setCode(tagValueList.at(1), name(), error);
         QLineEdit *edit = w->findChild<QLineEdit *>(QStringLiteral("edit"));
-        edit->setText(AutoCreateScriptUtil::quoteStr(strValue.at(0)));
+        edit->setText(wasListElement ? strValue.at(0) : AutoCreateScriptUtil::quoteStr(strValue.at(0)));
     } else if (strValue.count() == 2) {
         SelectBodyTypeWidget *bodyType = w->findChild<SelectBodyTypeWidget *>(QStringLiteral("bodytype"));
         bodyType->setCode(tagValueList.at(0), indexStr == 2 ? strValue.at(0) : QString(), name(), error);
