@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -34,16 +34,11 @@
 
 using namespace KSieveUi;
 
-SieveConditionEnvelope::SieveConditionEnvelope(QObject *parent)
-    : SieveCondition(QStringLiteral("envelope"), i18n("Envelope"), parent)
+SieveConditionEnvelope::SieveConditionEnvelope(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveCondition(sieveGraphicalModeWidget, QStringLiteral("envelope"), i18n("Envelope"), parent)
 {
 }
 
-SieveCondition *SieveConditionEnvelope::newAction()
-{
-    return new SieveConditionEnvelope;
-}
-
 QWidget *SieveConditionEnvelope::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
@@ -51,7 +46,7 @@ QWidget *SieveConditionEnvelope::createParamWidget(QWidget *parent) const
     lay->setMargin(0);
     w->setLayout(lay);
 
-    SelectAddressPartComboBox *selectAddressPart = new SelectAddressPartComboBox;
+    SelectAddressPartComboBox *selectAddressPart = new SelectAddressPartComboBox(mSieveGraphicalModeWidget);
     connect(selectAddressPart, &SelectAddressPartComboBox::valueChanged, this, &SieveConditionEnvelope::valueChanged);
     selectAddressPart->setObjectName(QStringLiteral("addresspartcombobox"));
     lay->addWidget(selectAddressPart);
@@ -60,7 +55,7 @@ QWidget *SieveConditionEnvelope::createParamWidget(QWidget *parent) const
     grid->setMargin(0);
     lay->addLayout(grid);
 
-    SelectMatchTypeComboBox *selectMatchCombobox = new SelectMatchTypeComboBox;
+    SelectMatchTypeComboBox *selectMatchCombobox = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     selectMatchCombobox->setObjectName(QStringLiteral("matchtypecombobox"));
     connect(selectMatchCombobox, &SelectMatchTypeComboBox::valueChanged, this, &SieveConditionEnvelope::valueChanged);
     grid->addWidget(selectMatchCombobox, 0, 0);
@@ -97,7 +92,7 @@ QString SieveConditionEnvelope::code(QWidget *w) const
 
     const QLineEdit *edit = w->findChild<QLineEdit *>(QStringLiteral("editaddress"));
     const QString addressStr = AutoCreateScriptUtil::createAddressList(edit->text().trimmed(), false);
-    return AutoCreateScriptUtil::negativeString(isNegative) + QStringLiteral("envelope %1 %2 %3 %4").arg(selectAddressPartStr).arg(matchTypeStr).arg(selectHeaderTypeStr).arg(addressStr);
+    return AutoCreateScriptUtil::negativeString(isNegative) + QStringLiteral("envelope %1 %2 %3 %4").arg(selectAddressPartStr, matchTypeStr, selectHeaderTypeStr, addressStr);
 }
 
 QStringList SieveConditionEnvelope::needRequires(QWidget *w) const
