@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,16 +31,11 @@
 
 using namespace KSieveUi;
 
-SieveConditionExists::SieveConditionExists(QObject *parent)
-    : SieveCondition(QStringLiteral("exists"), i18n("Exists"), parent)
+SieveConditionExists::SieveConditionExists(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveCondition(sieveGraphicalModeWidget, QStringLiteral("exists"), i18n("Exists"), parent)
 {
 }
 
-SieveCondition *SieveConditionExists::newAction()
-{
-    return new SieveConditionExists;
-}
-
 QWidget *SieveConditionExists::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
@@ -72,7 +67,7 @@ QString SieveConditionExists::code(QWidget *w) const
     const QString comparaison = combo->itemData(combo->currentIndex()).toString();
 
     const SelectHeaderTypeComboBox *value = w->findChild<SelectHeaderTypeComboBox *>(QStringLiteral("headervalue"));
-    return QStringLiteral("%1 %2").arg(comparaison).arg(value->code());
+    return QStringLiteral("%1 %2").arg(comparaison, value->code());
 }
 
 QString SieveConditionExists::help() const
