@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -173,7 +173,7 @@ void SelectHeadersWidget::setListHeaders(const QMap<QString, QString> &lst, cons
             }
         }
     }
-    Q_FOREACH (const QString &header, selectedHeaders) {
+    for (const QString &header : selectedHeaders) {
         if (!lst.contains(header)) {
             QListWidgetItem *item = new QListWidgetItem(header, this);
             item->setData(HeaderId, header);
