@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -30,7 +30,7 @@ class SelectSizeWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SelectSizeWidget(QWidget *parent = Q_NULLPTR);
+    explicit SelectSizeWidget(QWidget *parent = nullptr);
     ~SelectSizeWidget();
 
     QString code() const;
