@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,8 +19,8 @@
 
 #include "sievewidgetpageabstract.h"
 
-namespace KSieveUi
-{
+using namespace KSieveUi;
+
 SieveWidgetPageAbstract::SieveWidgetPageAbstract(QWidget *parent)
     : QWidget(parent),
       mType(BlockIf)
@@ -40,6 +40,3 @@ SieveWidgetPageAbstract::PageType SieveWidgetPageAbstract::pageType() const
 {
     return mType;
 }
-
-}
-
