@@ -60,14 +60,15 @@ namespace KSieve
 //
 
 Lexer::Lexer(const char *scursor, const char *send, int options)
-    : i(Q_NULLPTR)
+    : i(nullptr)
 {
     i = new Impl(scursor, send, options);
 }
 
 Lexer::~Lexer()
 {
-    delete i; i = Q_NULLPTR;
+    delete i;
+    i = nullptr;
 }
 
 bool Lexer::ignoreComments() const
@@ -651,7 +652,7 @@ MultiLineStart:
 
     assert(!lines.empty());
     lines.erase(--lines.end());   // don't include the lone dot.
-    result = lines.join(QStringLiteral("\n"));
+    result = lines.join(QLatin1Char('\n'));
     return true;
 }
 
